/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: NotificationSender.java 6218 2010-03-29 08:25:18Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.tests.rules.osgi;

import java.util.Date;

import org.mule.extras.client.MuleClient;
import org.objectweb.jasmine.rules.dispatcher.NotificationDispatcher;
import org.ow2.jasmine.event.beans.JasmineEventEB;
import org.ow2.jasmine.event.beans.JasmineEventNotification;

/**
 * Send notification depending on the type of the event
 * 
 * @author Florent Benoit
 */
public class NotificationSender {

	/**
	 * Dispatcher on the mule side.
	 */
	private static final String EVENT_DISPATCHER = "vm://MBeanCmd_dispatcher";
	
	/**
	 * Event.
	 */
	private static final String EVENT = 
		"mbeancmd_values_v1\n" + 
		"date;time;sname;server;domain;mbean;;Item\n" + 
		"2009/09/09 09:09:09;1252480149410;service:jmx:rmi:///jndi/rmi://localhost:1099/jrmpconnector_jonas_florent;florentServer;myDomain;droolsEvent;;myValueSentByDrools";	
	     

	/**
	 * Called by the first rule, but this rule shouldn't be called
	 * @param event
	 */
	public static void sendNotificationActionTest1(JasmineEventEB event) {
		// Shouldn't be called by any rules
		System.out.println("Sending a notification with notification ID 1. It shouldn't be called !!!!!!!!!!!!!!");
		sendNotification(event, 1);		
	}
	
	
	/**
	 * Send the given notification
	 * @param event
	 */
	private static void sendNotification(JasmineEventEB event, int notificationID) {
	
		 JasmineEventNotification notification = new JasmineEventNotification();
		 notification.setId(Integer.toString(notificationID));
		 notification.setMessage(event.getProbe());
		 // special level for notification ID
		 if (notificationID == 4) {
			 notification.setLevel("Error");
		 } else {
			 notification.setLevel("Info");
		 }
		 notification.setDate(new Date());
		 notification.setRule("test-rule");
		 notification.setStatus(false);
		 notification.addDetail("value", event.getValue().toString());
		 notification.addDetail("domain", event.getDomain());
		 notification.addDetail("server", event.getServer());
		 notification.addDetail("timestamp", event.getTimestamp().toString());
			 
		try {
		    // Save the notification in database
		    NotificationDispatcher.dispatchEvent(NotificationDispatcher.EventAction.SAVE_IN_DATABASE, notification);
		    // Export the notification as JMX notification
		    // NotificationDispatcher.dispatchEvent(NotificationDispatcher.EventAction.JMX_EXPORT, notification);
		    // Send a mail notification
		    // needs some configuration see MailSession1.properties
		    // NotificationDispatcher.dispatchEvent(NotificationDispatcher.EventAction.SEND_MAIL, notification,"from@address.com","to@address.com");
			System.out.println("Notification '" + notification + "' was sent to the");
		} catch (Exception e) {
			e.printStackTrace();
		}

	}

	public static void sendNotificationActionTest2(JasmineEventEB event) {
		// Send a notification
		System.out.println("Sending a notification with notification ID 2");
		sendNotification(event, 2);		
	}

	
	public static void sendNotificationActionTest3(JasmineEventEB event) {

		// Send an event
		System.out.println("Sending an event that should come back and handled by another rule");

		// Only one instance of the mule client
		try {
			MuleClient muleClient = new MuleClient();
			muleClient.dispatch(EVENT_DISPATCHER, EVENT, null);
		} catch (Exception e) {
			throw new RuntimeException("Unable to send new event", e);
		}

	}
		
	public static void sendNotificationActionTest4(JasmineEventEB event) {
		// Send a notification
		System.out.println("Sending a notification with notification ID 4");
		sendNotification(event, 4);		
	}
		

}
